<?php
/**
 * Helper class for Cookie Control 8 module
 *
 * @package     CookieControl8.CIVIC
 * @subpackage  Modules
 * @author      Civic Team <queries@civicuk.com>
 * @copyright   Copyright (C) 2018 Open Source Matters, Inc. All rights reserved.
 * @license     GNU/GPL v2 or later http://www.gnu.org/licenses/gpl-2.0.html
 *
 * Websites: https://www.civicuk.com
 * Documentation:  https://www.civicuk.com/cookie-control/v8/documentation
 */

// No direct access
defined('_JEXEC') or die('Restricted access');

/**
 * Helper class for Cookie Control 8 module
 * @since       1.0
 */
class ModCookieControlHelper
{
	/**
	 * Retrieves the cookie control parameters
	 *
	 * @param   array  $params An object containing the module parameters
	 * @return   array  $cookiecontrolSettings An object containing the module parameters
	 *
	 * @access public
	 */
	public static function getCCC( $params )
	{
		$colorMatch = '|^#([A-Fa-f0-9]{3}){1,2}$|';

		$cookiecontrolSettings['apiKey'] = $params->get('apiKey');
		$cookiecontrolSettings['product'] = $params->get('product');

		if (empty($params->get('version')) && empty($params->get('apiKey')))
		{
			$cookiecontrolSettings['version'] = 9;
		}
		elseif (empty($params->get('version')))
		{
			$cookiecontrolSettings['version'] = 8;
		}
		else
		{
			$cookiecontrolSettings['version'] = $params->get('version');
		}

		$cookiecontrolSettings['mode'] = $params->get('mode') ? $params->get('mode') : 'GDPR';
		$cookiecontrolSettings['logConsent'] = $params->get('logConsent');
		$cookiecontrolSettings['encodeCookie'] = $params->get('encodeCookie') ? $params->get('encodeCookie') : 'false';
		$cookiecontrolSettings['subDomains'] = $params->get('subDomains') ? $params->get('subDomains') : 'true';
		$cookiecontrolSettings['sameSiteCookie'] = $params->get('sameSiteCookie') ? $params->get('sameSiteCookie') : 'true';
		$cookiecontrolSettings['sameSiteValue'] = $params->get('sameSiteValue') ? $params->get('sameSiteValue') : 'Strict';
		$cookiecontrolSettings['onLoad'] = str_replace(array("\r\n", "\n", "\r", '  '), '', $params->get('onLoad'));

		$cookiecontrolSettings['initialState'] = $params->get('initialState') ? $params->get('initialState') : 'closed';
		$cookiecontrolSettings['position'] = $params->get('position');
		$cookiecontrolSettings['rejectButton'] = $params->get('rejectButton') ? $params->get('rejectButton') : 'false';
		$cookiecontrolSettings['theme'] = $params->get('theme');
		$cookiecontrolSettings['layout'] = $params->get('layout');
		$cookiecontrolSettings['expiry'] = $params->get('expiry');
		$cookiecontrolSettings['toggleType'] = $params->get('toggleType') ? $params->get('toggleType') : 'slider';
		$cookiecontrolSettings['closeStyle'] = $params->get('closeStyle') ? $params->get('closeStyle') : 'icon';
		$cookiecontrolSettings['notifyDismissButton'] = $params->get('notifyDismissButton') ? $params->get('notifyDismissButton') : 'true';
		$cookiecontrolSettings['settingsStyle'] = $params->get('settingsStyle') ? $params->get('settingsStyle') : 'button';
		$cookiecontrolSettings['acceptBehaviour'] = $params->get('acceptBehaviour') ? $params->get('acceptBehaviour') : 'all';
		$cookiecontrolSettings['closeOnGlobalChange'] = $params->get('closeOnGlobalChange') ? $params->get('closeOnGlobalChange') : 'true';

		$cookiecontrolSettings['highlightFocus'] = $params->get('highlightFocus') ? $params->get('highlightFocus') : 'false';
		$accessKey = $params->get('accessKey');
		$cookiecontrolSettings['accessKey'] = $accessKey ? str_replace(array("\r\n", "\n", "\r", '  '), '', $accessKey) : 'C';
		$cookiecontrolSettings['overlay'] = $params->get('overlay') ? $params->get('overlay') : 'true';
		$cookiecontrolSettings['outline'] = $params->get('outline') ? $params->get('overlay') : 'false';

		$cookiecontrolSettings['titleText'] = str_replace(array("\r\n", "\n", "\r", '  '), '', $params->get('titleText'));
		$cookiecontrolSettings['introText'] = str_replace(array("\r\n", "\n", "\r", '  '), '', $params->get('introText'));
		$cookiecontrolSettings['necessaryTitle'] = str_replace(array("\r\n", "\n", "\r", '  '), '', $params->get('necessaryTitle'));
		$cookiecontrolSettings['necessaryDescription'] = str_replace(array("\r\n", "\n", "\r", '  '), '', $params->get('necessaryDescription'));
		$cookiecontrolSettings['thirdPartyTitle'] = str_replace(array("\r\n", "\n", "\r", '  '), '', $params->get('thirdPartyTitle'));
		$cookiecontrolSettings['thirdPartyDescription'] = str_replace(array("\r\n", "\n", "\r", '  '), '', $params->get('thirdPartyDescription'));
		$cookiecontrolSettings['onText'] = str_replace(array("\r\n", "\n", "\r", '  '), '', $params->get('onText'));
		$cookiecontrolSettings['offText'] = str_replace(array("\r\n", "\n", "\r", '  '), '', $params->get('offText'));
		$cookiecontrolSettings['acceptText'] = str_replace(array("\r\n", "\n", "\r", '  '), '', $params->get('acceptText'));
		$cookiecontrolSettings['acceptSettings'] = str_replace(array("\r\n", "\n", "\r", '  '), '', $params->get('acceptSettings'));
		$cookiecontrolSettings['settingsText'] = str_replace(array("\r\n", "\n", "\r", '  '), '',  $params->get('settingsText'));
		$cookiecontrolSettings['acceptRecommended'] = str_replace(array("\r\n", "\n", "\r", '  '), '', $params->get('acceptRecommended'));
		$cookiecontrolSettings['rejectText'] = str_replace(array("\r\n", "\n", "\r", '  '), '', $params->get('rejectText'));
		$cookiecontrolSettings['rejectSettings'] = $params->get('rejectSettings') ? str_replace(array("\r\n", "\n", "\r", '  '), '', $params->get('rejectSettings')) : 'Reject All';
		$cookiecontrolSettings['notifyTitle'] = str_replace(array("\r\n", "\n", "\r", '  '), '', $params->get('notifyTitle'));
		$cookiecontrolSettings['notifyDescription'] = str_replace(array("\r\n", "\n", "\r", '  '), '', $params->get('notifyDescription'));
		$cookiecontrolSettings['privacyDescription'] = str_replace(array("\r\n", "\n", "\r", '  '), '', $params->get('privacyDescription'));
		$cookiecontrolSettings['privacyName'] = str_replace(array("\r\n", "\n", "\r", '  '), '', $params->get('privacyName'));
		$cookiecontrolSettings['privacyUpdateDate'] = str_replace(array("\r\n", "\n", "\r", '  '), '', $params->get('privacyUpdateDate'));
		$cookiecontrolSettings['privacyURL'] = $params->get('privacyURL');
		$cookiecontrolSettings['closeLabel'] = str_replace(array("\r\n", "\n", "\r", '  '), '', $params->get('closeLabel'));
		$cookiecontrolSettings['accessibilityAlert'] = str_replace(array("\r\n", "\n", "\r", '  '), '', $params->get('accessibilityAlert'));
		$cookiecontrolSettings['cornerButton'] = str_replace(array("\r\n", "\n", "\r", '  '), '', $params->get('cornerButton'));
		$cookiecontrolSettings['landmark'] = str_replace(array("\r\n", "\n", "\r", '  '), '', $params->get('landmark'));
		$cookiecontrolSettings['showVendors'] = str_replace(array("\r\n", "\n", "\r", '  '), '', $params->get('showVendors'));
		$cookiecontrolSettings['thirdPartyCookies'] = str_replace(array("\r\n", "\n", "\r", '  '), '', $params->get('thirdPartyCookies'));
		$cookiecontrolSettings['readMore'] = str_replace(array("\r\n", "\n", "\r", '  '), '', $params->get('readMore'));

		$cookiecontrolSettings['privacyDescriptionCCPA'] = str_replace(array("\r\n", "\n", "\r", '  '), '', $params->get('privacyDescriptionCCPA'));
		$cookiecontrolSettings['privacyNameCCPA'] = str_replace(array("\r\n", "\n", "\r", '  '), '', $params->get('privacyNameCCPA'));
		$cookiecontrolSettings['privacyUpdateDateCCPA'] = str_replace(array("\r\n", "\n", "\r", '  '), '', $params->get('privacyUpdateDateCCPA'));
		$cookiecontrolSettings['privacyURLCCPA'] = $params->get('privacyURLCCPA');

		$fontColor = $params->get('fontColor');
		$cookiecontrolSettings['fontColor'] = (empty($fontColor) || !preg_match($colorMatch, $fontColor)) ? '' : $fontColor;

		$fontSizeTitle = $params->get('fontSizeTitle');
		$cookiecontrolSettings['fontSizeTitle'] = (empty($fontSizeTitle) || !is_numeric($fontSizeTitle)) ? '1.2' : $fontSizeTitle;

		$fontFamily = $params->get('fontFamily');
		$cookiecontrolSettings['fontFamily'] = str_replace(array("\r\n", "\n", "\r", '  '), '', $fontFamily);

		$fontSizeHeaders = $params->get('fontSizeHeaders');
		$cookiecontrolSettings['fontSizeHeaders'] = (empty($fontSizeHeaders) || !is_numeric($fontSizeHeaders)) ? '1' : $fontSizeHeaders;

		$fontSize = $params->get('fontSize');
		$cookiecontrolSettings['fontSize'] = (empty($fontSize) || !is_numeric($fontSize)) ? '0.8' : $fontSize;

		$bgColor = $params->get('backgroundColor');
		$cookiecontrolSettings['backgroundColor'] = (empty($bgColor) || !preg_match($colorMatch, $bgColor)) ? '' : $bgColor;

		$toggleText = $params->get('toggleText');
		$cookiecontrolSettings['toggleText'] = (empty($toggleText) || !preg_match($colorMatch, $toggleText)) ? '' : $toggleText;

		$toggleColor = $params->get('toggleColor');
		$cookiecontrolSettings['toggleColor'] = (empty($toggleColor) || !preg_match($colorMatch, $toggleColor)) ? '' : $toggleColor;

		$toggleBg = $params->get('toggleBackground');
		$cookiecontrolSettings['toggleBackground'] = (empty($toggleBg) || !preg_match($colorMatch, $toggleBg)) ? '' : $toggleBg;

		$alertText = $params->get('alertText');
		$cookiecontrolSettings['alertText'] = (empty($alertText) || !preg_match($colorMatch, $alertText)) ? '' : $alertText;

		$alertBg = $params->get('alertBackground');
		$cookiecontrolSettings['alertBackground'] = (empty($alertBg) || !preg_match($colorMatch, $alertBg)) ? '' : $alertBg;

		$acceptTextColor = $params->get('acceptTextColor');
		$cookiecontrolSettings['acceptTextColor'] = (empty($acceptTextColor) || !preg_match($colorMatch, $acceptTextColor)) ? '' : $acceptTextColor;

		$acceptBg = $params->get('acceptBackground');
		$cookiecontrolSettings['acceptBackground'] = (empty($acceptBg) || !preg_match($colorMatch, $acceptBg)) ? '' : $acceptBg;

		$rejectTextColor = $params->get('rejectTextColor');
		$cookiecontrolSettings['rejectTextColor'] = (empty($rejectTextColor) || !preg_match($colorMatch, $rejectTextColor)) ? '' : $rejectTextColor;

		$rejectBg = $params->get('rejectBackground');
		$cookiecontrolSettings['rejectBackground'] = (empty($rejectBg) || !preg_match($colorMatch, $rejectBg)) ? '' : $rejectBg;

		$closeTextColor = $params->get('closeTextColor');
		$cookiecontrolSettings['closeTextColor'] = (empty($closeTextColor) || !preg_match($colorMatch, $closeTextColor)) ? '' : $closeTextColor;

		$closeBackground = $params->get('closeBackground');
		$cookiecontrolSettings['closeBackground'] = (empty($closeBackground) || !preg_match($colorMatch, $closeBackground)) ? '' : $closeBackground;

		$notifyFontColor = $params->get('notifyFontColor');
		$cookiecontrolSettings['notifyFontColor'] = (empty($notifyFontColor) || !preg_match($colorMatch, $notifyFontColor)) ? '' : $notifyFontColor;

		$notifyBackgroundColor = $params->get('notifyBackgroundColor');
		$cookiecontrolSettings['notifyBackgroundColor'] = (empty($notifyBackgroundColor) || !preg_match($colorMatch, $notifyBackgroundColor)) ? '' : $notifyBackgroundColor;

		$cookiecontrolSettings['buttonIcon'] = $params->get('buttonIcon');

		$buttonIconWidth = $params->get('buttonIconWidth');
		$cookiecontrolSettings['buttonIconWidth'] = (empty($buttonIconWidth) || !is_numeric($buttonIconWidth)) ? '64' : $buttonIconWidth;

		$buttonIconHeight = $params->get('buttonIconHeight');
		$cookiecontrolSettings['buttonIconHeight'] = (empty($buttonIconHeight) || !is_numeric($buttonIconHeight)) ? '64' : $buttonIconHeight;

		$cookiecontrolSettings['removeIcon'] = $params->get('removeIcon');
		$cookiecontrolSettings['removeAbout'] = $params->get('removeAbout');

		$necessaryCookies = $params->get('necessaryCookies');
		$cookiecontrolSettings['necessaryCookies'] = (empty($necessaryCookies)) ? '' : explode(',', $necessaryCookies);

		$excludedCountries = $params->get('excludedCountries');
		$cookiecontrolSettings['excludedCountries'] = (empty($excludedCountries)) ? '' : explode(',', $excludedCountries);

		$cookiecontrolSettings['locale'] = $params->get('locale') ? str_replace(array("\r\n", "\n", "\r", '  '), '', $params->get('locale')) : '';

		// Get the repeatable field value and decode it
		$cookiecontrolSettings['altLanguages_list'] = json_decode($params->get('altLanguages_list'), true);

		// Get the repeatable field value and decode it
		$cookiecontrolSettings['optionalCookiesSubform'] = $params->get('optionalCookiesSubform');

		if (!empty($cookiecontrolSettings['optionalCookiesSubform']) && count((array) $cookiecontrolSettings['optionalCookiesSubform']) > 0)
		{
			foreach ($cookiecontrolSettings['optionalCookiesSubform'] as $key => $val)
			{
				if (!isset($val->optionalCookieslawfulBasis)
					|| ($val->optionalCookieslawfulBasis == ''))
				{
					$cookiecontrolSettings['optionalCookiesSubform']->$key->optionalCookieslawfulBasis = 'consent';
				}
			}
		}

		$cookiecontrolSettings['iabCMP'] = $params->get('iabCMP') ? $params->get('iabCMP') : 'false';
		$cookiecontrolSettings['iabfullLegalDescriptions'] = $params->get('fullLegalDescriptions') ? $params->get('fullLegalDescriptions') : 'true';
		$cookiecontrolSettings['iabdropDowns'] = $params->get('dropDowns') ? $params->get('dropDowns') : 'false';
		$cookiecontrolSettings['iabsaveOnlyOnClose'] = $params->get('saveOnlyOnClose') ? $params->get('saveOnlyOnClose') : 'false';
		$cookiecontrolSettings['iabpublisherCC'] = $params->get('iabpublisherCC') ? str_replace(array("\r\n", "\n", "\r", '  '), '', $params->get('iabpublisherCC')) : 'GB';
		$cookiecontrolSettings['gdprAppliesGlobally'] = $params->get('gdprAppliesGlobally') ? $params->get('gdprAppliesGlobally') : 'true';
		$cookiecontrolSettings['recommendedState1'] = $params->get('recommendedState1') ? $params->get('recommendedState1') : 'false';
		$cookiecontrolSettings['recommendedState2'] = $params->get('recommendedState2') ? $params->get('recommendedState2') : 'false';
		$cookiecontrolSettings['recommendedState3'] = $params->get('recommendedState3') ? $params->get('recommendedState3') : 'false';
		$cookiecontrolSettings['recommendedState4'] = $params->get('recommendedState4') ? $params->get('recommendedState4') : 'false';
		$cookiecontrolSettings['recommendedState5'] = $params->get('recommendedState5') ? $params->get('recommendedState5') : 'false';
		$cookiecontrolSettings['iabLabel'] = str_replace(array("\r\n", "\n", "\r", '  '), '', $params->get('iabLabel'));
		$cookiecontrolSettings['iabDescription'] = str_replace(array("\r\n", "\n", "\r", '  '), '', $params->get('iabDescription'));
		$cookiecontrolSettings['iabConfigure'] = str_replace(array("\r\n", "\n", "\r", '  '), '', $params->get('iabConfigure'));
		$cookiecontrolSettings['iabpanelTitle'] = str_replace(array("\r\n", "\n", "\r", '  '), '', $params->get('iabpanelTitle'));
		$cookiecontrolSettings['iabpanelIntro'] = str_replace(array("\r\n", "\n", "\r", '  '), '', $params->get('iabpanelIntro'));
		$cookiecontrolSettings['iabpanelIntro1'] = str_replace(array("\r\n", "\n", "\r", '  '), '', $params->get('iabpanelIntro1'));
		$cookiecontrolSettings['iabpanelIntro2'] = str_replace(array("\r\n", "\n", "\r", '  '), '', $params->get('iabpanelIntro2'));
		$cookiecontrolSettings['iabpanelIntro3'] = str_replace(array("\r\n", "\n", "\r", '  '), '', $params->get('iabpanelIntro3'));
		$cookiecontrolSettings['iaaboutIab'] = str_replace(array("\r\n", "\n", "\r", '  '), '', $params->get('iaaboutIab'));
		$cookiecontrolSettings['iabName'] = str_replace(array("\r\n", "\n", "\r", '  '), '', $params->get('iabName'));
		$cookiecontrolSettings['iabLink'] = str_replace(array("\r\n", "\n", "\r", '  '), '', $params->get('iabLink'));
		$cookiecontrolSettings['iabpanelBack'] = str_replace(array("\r\n", "\n", "\r", '  '), '', $params->get('iabpanelBack'));
		$cookiecontrolSettings['iabvendorTitle'] = str_replace(array("\r\n", "\n", "\r", '  '), '', $params->get('iabvendorTitle'));
		$cookiecontrolSettings['iabvendorConfigure'] = str_replace(array("\r\n", "\n", "\r", '  '), '', $params->get('iabvendorConfigure'));
		$cookiecontrolSettings['iabvendorBack'] = str_replace(array("\r\n", "\n", "\r", '  '), '', $params->get('iabvendorBack'));
		$cookiecontrolSettings['iabacceptAll'] = str_replace(array("\r\n", "\n", "\r", '  '), '', $params->get('iabacceptAll'));
		$cookiecontrolSettings['iabrejectAll'] = str_replace(array("\r\n", "\n", "\r", '  '), '', $params->get('iabrejectAll'));
		$cookiecontrolSettings['iabBack'] = str_replace(array("\r\n", "\n", "\r", '  '), '', $params->get('iabBack'));
		$cookiecontrolSettings['iabpurposeLegitimateInterest'] = str_replace(array("\r\n", "\n", "\r", '  '), '', $params->get('iabpurposeLegitimateInterest'));
		$cookiecontrolSettings['iabvendorLegitimateInterest'] = str_replace(array("\r\n", "\n", "\r", '  '), '', $params->get('iabvendorLegitimateInterest'));
		$cookiecontrolSettings['iabrelyLegitimateInterest'] = str_replace(array("\r\n", "\n", "\r", '  '), '', $params->get('iabrelyLegitimateInterest'));
		$cookiecontrolSettings['iabrelyConsent'] = str_replace(array("\r\n", "\n", "\r", '  '), '', $params->get('iabrelyConsent'));
		$cookiecontrolSettings['iabvendors'] = str_replace(array("\r\n", "\n", "\r", '  '), '', $params->get('iabvendors'));
		$cookiecontrolSettings['iabpurposes'] = str_replace(array("\r\n", "\n", "\r", '  '), '', $params->get('iabpurposes'));
		$cookiecontrolSettings['iabfeatures'] = str_replace(array("\r\n", "\n", "\r", '  '), '', $params->get('iabfeatures'));
		$cookiecontrolSettings['iabspecialFeatures'] = str_replace(array("\r\n", "\n", "\r", '  '), '', $params->get('iabspecialFeatures'));
		$cookiecontrolSettings['iabspecialPurposes'] = str_replace(array("\r\n", "\n", "\r", '  '), '', $params->get('iabspecialPurposes'));
		$cookiecontrolSettings['iabdataUse'] = str_replace(array("\r\n", "\n", "\r", '  '), '', $params->get('iabdataUse'));
		$cookiecontrolSettings['iabsavePreferences'] = str_replace(array("\r\n", "\n", "\r", '  '), '', $params->get('iabsavePreferences'));
		$cookiecontrolSettings['iablegalDescription'] = str_replace(array("\r\n", "\n", "\r", '  '), '', $params->get('iablegalDescription'));

		$cookiecontrolSettings['cookieMaxAge'] = str_replace(array("\r\n", "\n", "\r", '  '), '', $params->get('cookieMaxAge'));
		$cookiecontrolSettings['usesNonCookieAccessTrue'] = str_replace(array("\r\n", "\n", "\r", '  '), '', $params->get('usesNonCookieAccessTrue'));
		$cookiecontrolSettings['usesNonCookieAccessFalse'] = str_replace(array("\r\n", "\n", "\r", '  '), '', $params->get('usesNonCookieAccessFalse'));
		$cookiecontrolSettings['storageDisclosures'] = str_replace(array("\r\n", "\n", "\r", '  '), '', $params->get('storageDisclosures'));
		$cookiecontrolSettings['disclosureDetailsColumn'] = str_replace(array("\r\n", "\n", "\r", '  '), '', $params->get('disclosureDetailsColumn'));
		$cookiecontrolSettings['disclosurePurposesColumn'] = str_replace(array("\r\n", "\n", "\r", '  '), '', $params->get('disclosurePurposesColumn'));
		$cookiecontrolSettings['seconds'] = str_replace(array("\r\n", "\n", "\r", '  '), '', $params->get('seconds'));
		$cookiecontrolSettings['minutes'] = str_replace(array("\r\n", "\n", "\r", '  '), '', $params->get('minutes'));
		$cookiecontrolSettings['hours'] = str_replace(array("\r\n", "\n", "\r", '  '), '', $params->get('hours'));
		$cookiecontrolSettings['days'] = str_replace(array("\r\n", "\n", "\r", '  '), '', $params->get('days'));

		return $cookiecontrolSettings;

	}
}
